Basic
.
A paragraph with **strong** and _emphasis_ text.

> A block quote with a [link](http://example.com) and some `code`.
.
<p data-sourcepos="1:1-1:48">A paragraph with <strong data-sourcepos="1:18-1:27">strong</strong> and <em data-sourcepos="1:33-1:42">emphasis</em> text.</p>
<blockquote data-sourcepos="3:1-3:66">
<p data-sourcepos="3:3-3:66">A block quote with a <a data-sourcepos="3:24-3:49" href="http://example.com">link</a> and some <code data-sourcepos="3:60-3:65">code</code>.</p>
</blockquote>
.
